IgnorePatternRules enum

Inheritance
Available extensions

Values

suffix → const IgnorePatternRules
const IgnorePatternRules(position: PatternPosition.start, description: "Matches any number of characters")
single → const IgnorePatternRules
const IgnorePatternRules(position: PatternPosition.any, description: "Matches exactly one character")
contains → const IgnorePatternRules
const IgnorePatternRules(position: PatternPosition.any, description: "Matches nested directories")
pathFromRoot → const IgnorePatternRules
const IgnorePatternRules(position: PatternPosition.start, description: "Relative to root start")
exactMatch → const IgnorePatternRules
const IgnorePatternRules(position: PatternPosition.any, description: "Exact name match")

Properties

description String
final
example PatternExamples

Available on IgnorePatternRules, provided by the IgnorePatternRulesEvaluator extension

no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
pattern String
no setter
position PatternPosition
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patternMatches({required String testPattern, required String inputPattern}) bool

Available on IgnorePatternRules, provided by the IgnorePatternRulesEvaluator extension

Checks if testPattern matches an inputPattern testPattern may for example be a pattern
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

detectRule(String pattern) IgnorePatternRules

Constants

values → const List<IgnorePatternRules>
A constant List of the values in this enum, in order of their declaration.